---------------------------------------------------------
------------------Simple Animation lua------------------------------
---------------------------------------------------------

local function anim(time_per_frame, frames)
	local newframes = {}
	
	for i = 1, #frames do
		for j = 1, time_per_frame do
			table.insert(newframes, frames[i])
		end
	end
	
	return newframes
end

SIMPLE_ANIMAL_DEFINITIONS["tennahd"] = {
  ["stand"] = {A, B},
  ["stand_left"] = {C, D},
  ["stand_right"] = {E, F},
  ["walk"] = {J, G},
  ["walk_left"] = {K, H},
  ["walk_right"] = {L, I},
  ["run"] = {A, J},
  ["run_left"] = {C, K},
  ["run_right"] = {E, L},
  ["drift_left"] = {M, N},
  ["drift_right"] = {O, P},
  ["spin"] = {Q},
  ["squish"] = {R},
  ["trick"] = {Z+12},
  ["pain"] = {Q, Q, T, T, U, U},
  ["fall"] = {Z+4},
  ["pointup"] = {Z+8}, 
  ["bow"] = {Z+5, Z+5, Z+5, Z+6, Z+6, Z+6, Z+7, Z+7, Z+7},
  ["tvtime"] = {V, V, V, V, W, W, W, W},
  ["dance"] = {Z+9, Z+9, Z+10, Z+10, Z+11, Z+11, Z+10, Z+10},
  ["goal"] = {X, X, Y, Y, Z, Z, Z+1, Z+1, Z+2, Z+2, Z+3, Z+3},
  ["taunt"] = anim(4, {Z+13, Z+14, Z+15, Z+16, Z+15, Z+14, Z+13, Z+14, Z+15}),
}

function SIMPLE_ANIMAL_HOOKS.tennahd(mobj, sequences)
   if mobj.player and mobj.skin == "tennahd"
    local helpers = _G["SIMPLE_ANIMAL_HELPERS"]
	
	if mobj.player.taunttimer then
	  return "taunt"
	elseif helpers.isGrow(mobj)
      return "dance"
	elseif helpers.isInvincible(mobj)
      return "tvtime"
	elseif helpers.isRespawning(mobj)
      return "pain"
	elseif helpers.isAirborne(mobj) and not helpers.isTricking(mobj) and not (helpers.isSquished(mobj) or helpers.isSpinning(mobj) or helpers.isPained(mobj))
       if not helpers.isAscending(mobj) and not helpers.isRespawning(mobj)
			return "fall"
		end  

    elseif helpers.isNoSpeed(mobj) and helpers.isFinished(mobj) and not (helpers.isSquished(mobj) or helpers.isSpinning(mobj) or helpers.isPained(mobj))
      return "bow"	
--	elseif helpers.isCountdown(mobj) --bugued?
--		return "bow"
	elseif helpers.isCountdownCharging(mobj)
		return "pointup"
    end
  end
end


---------------------------------------------------------
------------------Taunt lua------------------------------
---------------------------------------------------------

local tauntskins = "tennahd"
local TICRATE = TICRATE

-------------------------------------------------------------------
//Functions
-------------------------------------------------------------------

local function TauntTrick(p)
	if acrobatics == nil then return end //Add Acrobatics check, you're using acro data
	if p.trickgrade == 0 then return end
	
    if p.sincelasttrick == 34
		p.taunttimer = TICRATE
	end
end

local function TauntBasicTrick(p)
	if acrobasics == nil then return end //Add Acrobasics check, and i need this because sincelasttrick is longer for some reason
	if p.trickgrade == 0 then return end
	
    if p.sincelasttrick == 69 //nice
		p.taunttimer = TICRATE
	end
end



-------------------------------------------------------------------
//ThinkFrame and Timer Shit
-------------------------------------------------------------------
local function KillTaunt(p)
	if p.kartstuff[k_spinouttimer] 
	or p.playerstate == PST_DEAD
	or p.kartstuff[k_squishedtimer]
	or (acrobatics != nil and p.trickactive)
	then return true
	else return false
	end
end

addHook("MapLoad", do     
    for player in players.iterate do
        player.taunttimer = nil
    end
end)

addHook("PostThinkFrame", do
    for p in players.iterate do    
        if not p.mo or not p.mo.valid continue end 
		if (p.mo.skin != tauntskins) or p.spectator continue end //Stop working. You have no use to me.
		
        if p.taunttimer == nil or KillTaunt(p) then p.taunttimer = 0 end //Reset
		if p.taunttimer > 0 then p.taunttimer = max($-1, 0) end //Timer
		//print(p.taunttimer)
		
		TauntTrick(p)
		TauntBasicTrick(p)
    end
end)

-------------------------------------------------------------------
//Playerblablabla
-------------------------------------------------------------------
local function Gottem(player, inflictor, source)
  if not (source and source.player) then return end

  if source.player != player
    if (source.player.mo and source.player.mo.valid) and (source.player.mo.skin == tauntskins)
      if not (source.player.kartstuff[k_spinouttimer] and source.player.kartstuff[k_squishedtimer])
        source.player.taunttimer = TICRATE
      end
    end
  end
end
addHook("PlayerSpin", Gottem)
addHook("PlayerExplode", Gottem)
addHook("PlayerSquish", Gottem)